#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
#include <stack>
#include <unordered_set>
#include <iomanip>

struct Seg
{
    int64_t x;
    int64_t ylow, yhigh;
    bool operator<(const Seg& other) const
    {
        return x < other.x;
    }
};

struct Frac
{
    Frac(int64_t n, int64_t d) : num(n), denom(d)
    {
        if (d < 0)
        {
            num *= -1;
            denom *= -1;
        }
    }
    int64_t num;
    int64_t denom;
    bool operator < (const Frac& other) const
    {
        return num * other.denom < denom* other.num;
    }
};

struct UnionFind
{
    UnionFind(int n)
    {
        parent.resize(n);
        size.resize(n);
        for (int i = 0; i < n; i++)
        {
            parent[i] = i;
            size[i] = 1;
        }
    }

    int find(int i)
    {
        while (parent[i] != i)
        {
            i = parent[i];
        }
        return i;
    }

    struct Undo
    {
        int r1, r2;
        int oldr1parent;
        int oldr2size;
    };

    void takeUnion(int i, int j)
    {
        int r1 = find(i);
        int r2 = find(j);
        if (r1 != r2)
        {
            if (size[r2] < size[r1])
                std::swap(r1, r2);
            undoq.push({ r1, r2, parent[r1], size[r2] });
            parent[r1] = r2;
            size[r2] += size[r1];
        }
    }

    void undo(int idx)
    {
        while (undoq.size() > idx)
        {
            auto u = undoq.top();
            undoq.pop();
            parent[u.r1] = u.oldr1parent;
            size[u.r2] = u.oldr2size;
        }
    }

    std::stack<Undo> undoq;

    std::vector<int> parent;
    std::vector<int> size;
};

struct Event
{
    Frac time;
    bool birth;
    int seg1, seg2;
    int oppindex;
    bool operator<(const Event& other) const
    {
        if (time < other.time)
            return true;
        if (other.time < time)
            return false;
        if (birth && !other.birth) return true;
        return false;
    }
};


double binarySearch(int n, UnionFind &uf, const std::vector<Event>& events, int lo, int hi, Frac &birth)
{
    if (lo == hi)
    {
        int i = events[lo].seg1;
        int j = events[lo].seg2;
        if (events[lo].birth)
        {
            int pi = uf.find(i);
            int pj = uf.find(j);
            if(pi != pj && uf.size[pi] + uf.size[pj] == n)
            {
                birth = events[lo].time;
//                std::cout << "Set birth to " << birth.num << "/" << birth.denom << std::endl;
            }
        }
        else
        {
            int pi = uf.find(i);
            int pj = uf.find(j);
            if(pi != pj && uf.size[pi] + uf.size[pj] == n)
            {
                Frac death = events[lo].time;
                if (birth.denom == 0)
                {
                    std::cout << -1 << std::endl;
                    exit(0);
                }
  //              std::cout << "Set death to " << death.num << "/" << death.denom << std::endl;
                double dt = double(death.num * birth.denom - death.denom * birth.num) / double(death.denom * birth.denom);
//                std::cout << "Segment is " << dt << std::endl;
                return dt;
            }
        }
        return 0;
    }

    int mid = lo + (hi - lo) / 2;
    int oldq = uf.undoq.size();
    for(int i=mid+1; i<=hi; i++)
    {
        if(!events[i].birth && events[i].oppindex < lo)
            uf.takeUnion(events[i].seg1, events[i].seg2);
    }

    double answer = binarySearch(n, uf, events, lo, mid, birth);
    uf.undo(oldq);

    for(int i=lo; i<=mid; i++)
    {
        if(events[i].birth && events[i].oppindex > hi)
            uf.takeUnion(events[i].seg1, events[i].seg2);
    }
    answer += binarySearch(n, uf, events, mid + 1, hi, birth);
    uf.undo(oldq);    
    return answer;
}

int main()
{
    int n;
    int64_t w;
    std::cin >> n >> w;

    std::vector<Seg> segs(n);
    for (int i = 0; i < n; i++)
        std::cin >> segs[i].x >> segs[i].ylow >> segs[i].yhigh;
    std::sort(segs.begin(), segs.end());

  
    std::vector<Event> events;
    Frac zero{ 0,1 };

    for (int i = 0; i < n; i++)
    {
        for (int j = i + 1; j < n; j++)
        {
            Frac time1{ segs[j].ylow * segs[i].x - segs[i].yhigh * segs[j].x, segs[j].ylow - segs[i].yhigh };
            Frac time2{ segs[j].yhigh * segs[i].x - segs[i].ylow * segs[j].x, segs[j].yhigh - segs[i].ylow };
            if (time2 < time1)
                std::swap(time1, time2);
            if (segs[i].yhigh < segs[j].ylow || segs[j].yhigh < segs[i].ylow)
            {
                if (zero < time1)
                    continue;
                if (zero < time2)
                    time2 = zero;
            }
            else
            {
                time2 = time1;
                time1 = Frac{ -1,0 };
                if (zero < time2)
                {
                    time2 = zero;
                }
            }
            events.push_back({ time1, true, i, j });
            events.push_back({ time2, false, i, j });
        }
    }
    int nevents = events.size();
    std::vector<int> birthidx(nevents/2);
    for(int i=0; i<nevents; i++)
        events[i].oppindex = i/2;
    
    std::sort(events.begin(), events.end());
    
    for(int i=0; i<nevents; i++)
    {
        if(events[i].birth)
        {
            birthidx[events[i].oppindex] = i;
        }
        else
        {
            int origidx = events[i].oppindex;
            events[i].oppindex = birthidx[origidx];
            events[birthidx[origidx]].oppindex = i;
        }
    }
    
    UnionFind uf(n);
    Frac birth{ -1,0 };
    if (events.size() == 0)
    {
        std::cout << (n == 1 ? "-1" : "0") << std::endl;
        return 0;
    }
    std::cout << std::setprecision(30) << binarySearch(n, uf, events, 0, events.size() - 1, birth) << std::endl;;
}
