#include <iostream>
#include <iomanip>
#include <vector>
#include <algorithm>

using namespace std;

struct PT {
    long x, y;
    bool l;
};

struct EVT {
    int a, b;
    double loc;
};

int main() {
    int N, X;
    cin >> N >> X;
    vector<PT> points;
    for (int i = 0; i < N; i++) {
        int x, yl, yh;
        cin >> x >> yl >> yh;
        points.push_back({x, yl, true});
        points.push_back({x, yh, false});
    }
    sort(points.begin(), points.end(), [](const PT& a, const PT& b) { return a.x < b.x; });
    vector<PT> sweepline = points;
    sort(sweepline.begin(), sweepline.end(), [](const PT& a, const PT& b) { return a.y < b.y; });
    vector<int> overlap(2 * N - 1);
    overlap[0] = 1;
    for (int i = 1; i < 2 * N - 1; i++) {
        if (sweepline[i].l) {
            overlap[i] = overlap[i - 1] + 1;
        } else {
            overlap[i] = overlap[i - 1] - 1;
        }
    }
    vector<int> hist(N + 1);
    for (int i = 0; i < 2 * N - 1; i++) hist[overlap[i]]++;
    if (hist[0] == 0) {
        cout << -1 << endl;
        return 0;
    }

    vector<int> idx(2 * N);
    for (int i = 0; i < 2 * N; i++) {
        for (int j = 0; j < 2 * N; j++) {
            if (points[i].x == sweepline[j].x && points[i].y == sweepline[j].y) {
                idx[i] = j;
                break;
            }
        }
    }

    vector<EVT> events;
    for (int i = 0; i < 2 * N; i++) {
        if (points[i].y == 0) continue;
        for (int j = i + 1; j < 2 * N; j++) {
            if (points[i].x == points[j].x) continue;
            if (points[j].y == 0) continue;
            if (points[i].y > 0 && points[j].y < 0) continue;
            if (points[i].y < 0 && points[j].y > 0) continue;
            double loc = ((double) (points[j].x * (points[j].y - points[i].y) - (points[j].x - points[i].x) * points[j].y)) / (points[j].y - points[i].y);
            if (loc >= 0) continue;
            if (points[i].y < points[j].y) {
                events.push_back({i, j, loc});
            } else {
                events.push_back({j, i, loc});
            }
        }
    }
    stable_sort(events.begin(), events.end(), [](const EVT& a, const EVT& b) { return a.loc < b.loc; });
    double ans = 0;
    double prev = -1.0e30;
    for (auto &e : events) {
        if (hist[0] == 0) ans += e.loc - prev;
        if (sweepline[idx[e.a]].l && !sweepline[idx[e.b]].l) {
            hist[overlap[idx[e.a]]]--;
            overlap[idx[e.a]] -= 2;
            hist[overlap[idx[e.a]]]++;
        } else if (!sweepline[idx[e.a]].l && sweepline[idx[e.b]].l) {
            hist[overlap[idx[e.a]]]--;
            overlap[idx[e.a]] += 2;
            hist[overlap[idx[e.a]]]++;
        }
        swap(sweepline[idx[e.a]], sweepline[idx[e.b]]);
        idx[e.a]++;
        idx[e.b]--;
        prev = e.loc;
    }
    if (hist[0] == 0) ans -= prev;
    cout << setprecision(12) << ans << endl;
}
